==> vocalpy-0.9.5.tar.gz: vocalpy-0.9.5/docs/index.md <==
---
jupytext:
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.14.5
kernelspec:
  display_name: Python 3 (ipykernel)
  language: python
  name: python3
---

::::{grid}
:reverse:
:gutter: 2 1 1 1
:margin: 4 4 1 1

:::{grid-item}
:columns: 8
:class: sd-fs-3

A core package for acoustic communication research in Python.
:::

:::{grid-item}
:columns: 4

```{image} ./_static/vocalpy-secondary.png
:width: 150px
```
:::

::::

VocalPy is a Python library for researchers studying how animals communicate with sound.
It is the core package of the [VocalPy community](http://www.vocalpy.org/).

**Useful links**:
[Installation](installation) | 
[Source code](https://github.com/vocalpy/vocalpy) | 
[Issue tracker](https://github.com/vocalpy/vocalpy/issues) |
[Report a bug or request a feature](https://github.com/vocalpy/vocalpy/issues/new/choose) | 
[Forum](https://forum.vocalpy.org/)

:::::{grid} 2

::::{grid-item-card}

Getting started
^^^^^^^^^^^^^^^

New to VocalPy? Check out the Getting Started section. 
It will tell you how to install VocalPy, 
introduce you to VocalPy's key concepts,
and give you links to additional tutorials.

+++

:::{button-ref} getting_started/index
:expand:
:color: secondary
:click-parent:

To the Getting Started section

:::

::::

::::{grid-item-card}

User guide
^^^^^^^^^^^^^^^

The user guide provides more in-depth tutorials, 
as well as how-to's that walk you through achieving specific tasks.
This guide also provides in-depth information on the
concepts of VocalPy, with useful background information and explanation.

+++

:::{button-ref} user/index
:expand:
:color: secondary
:click-parent:

To the user guide

:::

::::

::::{grid-item-card}

API reference
^^^^^^^^^^^^^^^

The API reference guide contains a detailed description of the functions,
modules, and objects included in VocalPy. This reference describes how the
methods work and which parameters can be used. It assumes that you have an
understanding of the key concepts.

+++

:::{button-ref} api/index
:expand:
:color: secondary
:click-parent:

To the API Reference

:::

::::

::::{grid-item-card}

Contributor's guide
^^^^^^^^^^^^^^^^^^^

Want to add to the codebase? Can help add translation or a flowchart to the
documentation? The contributing guidelines will guide you through the
process of improving VocalPy.

+++

:::{button-ref} contributing/index
:expand:
:color: secondary
:click-parent:

To the contributor's guide

:::

::::

:::::

```{toctree}
:hidden: true
:maxdepth: 2

getting_started/index
user/index
api/index
development/index
```

# Support

To report a bug or request a feature (such as a new annotation format), 
please use the issue tracker on GitHub:  
<https://github.com/vocalpy/vocalpy/issues>

To ask a question about vocalpy, discuss its development, 
or share how you are using it, 
please start a new topic on the VocalPy forum 
with the vocalpy tag:  
<https://forum.vocalpy.org/>

# Contribute

- Issue Tracker: <https://github.com/vocalpy/vocalpy/issues>
- Source Code: <https://github.com/vocalpy/vocalpy>

# License

The project is licensed under the
[BSD license](https://github.com/vocalpy/vocalpy/blob/master/LICENSE).

# CHANGELOG

You can see project history and work in progress in the
[CHANGELOG](https://github.com/vocalpy/vocalpy/blob/main/doc/CHANGELOG.md).

# Citation

If you use vocalpy, please cite the DOI:

```{image} https://zenodo.org/badge/DOI/10.5281/zenodo.7905426.svg
:target: https://doi.org/10.5281/zenodo.7905426
```

==> vocalpy-0.10.0.tar.gz: vocalpy-0.10.0/docs/index.md <==
---
jupytext:
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.14.5
kernelspec:
  display_name: Python 3 (ipykernel)
  language: python
  name: python3
---

::::{grid}
:reverse:
:gutter: 2 1 1 1
:margin: 4 4 1 1

:::{grid-item}
:columns: 8
:class: sd-fs-3

A core package for acoustic communication research in Python.
:::

:::{grid-item}
:columns: 4

```{image} ./images/vocalpy-secondary.png
:width: 150px
```
:::

::::

VocalPy is a Python library for researchers studying how animals communicate with sound.
It is the core package of the [VocalPy community](http://www.vocalpy.org/).

**Useful links**:
[Installation](installation) | 
[Source code](https://github.com/vocalpy/vocalpy) | 
[Issue tracker](https://github.com/vocalpy/vocalpy/issues) |
[Report a bug or request a feature](https://github.com/vocalpy/vocalpy/issues/new/choose) | 
[Forum](https://forum.vocalpy.org/)

:::::{grid} 2

::::{grid-item-card}

Getting started
^^^^^^^^^^^^^^^

New to VocalPy? Check out the Getting Started section. 
It will tell you how to install VocalPy, 
introduce you to VocalPy's key concepts,
and give you links to additional tutorials.

+++

:::{button-ref} getting_started/index
:expand:
:color: secondary
:click-parent:

To the Getting Started section

:::

::::

::::{grid-item-card}

User guide
^^^^^^^^^^^^^^^

The user guide provides more in-depth tutorials, 
as well as how-to's that walk you through achieving specific tasks.
This guide also provides in-depth information on the
concepts of VocalPy, with useful background information and explanation.

+++

:::{button-ref} user/index
:expand:
:color: secondary
:click-parent:

To the user guide

:::

::::

::::{grid-item-card}

API reference
^^^^^^^^^^^^^^^

The API reference guide contains a detailed description of the functions,
modules, and objects included in VocalPy. This reference describes how the
methods work and which parameters can be used. It assumes that you have an
understanding of the key concepts.

+++

:::{button-ref} api/index
:expand:
:color: secondary
:click-parent:

To the API Reference

:::

::::

::::{grid-item-card}

Contributor's guide
^^^^^^^^^^^^^^^^^^^

Want to add to the codebase? Can help add translation or a flowchart to the
documentation? The contributing guidelines will guide you through the
process of improving VocalPy.

+++

:::{button-ref} contributing/index
:expand:
:color: secondary
:click-parent:

To the contributor's guide

:::

::::

:::::

```{toctree}
:hidden: true
:maxdepth: 2

getting_started/index
user/index
api/index
development/index
```

# Support

To report a bug or request a feature (such as a new annotation format), 
please use the issue tracker on GitHub:  
<https://github.com/vocalpy/vocalpy/issues>

To ask a question about vocalpy, discuss its development, 
or share how you are using it, 
please start a new topic on the VocalPy forum 
with the vocalpy tag:  
<https://forum.vocalpy.org/>

# Contribute

- Issue Tracker: <https://github.com/vocalpy/vocalpy/issues>
- Source Code: <https://github.com/vocalpy/vocalpy>

# License

The project is licensed under the
[BSD license](https://github.com/vocalpy/vocalpy/blob/master/LICENSE).

# CHANGELOG

You can see project history and work in progress in the
[CHANGELOG](https://github.com/vocalpy/vocalpy/blob/main/doc/CHANGELOG.md).

# Citation

If you use vocalpy, please cite the DOI:

```{image} https://zenodo.org/badge/DOI/10.5281/zenodo.7905426.svg
:target: https://doi.org/10.5281/zenodo.7905426
```
